==> aws-cdk-scala_2.12-0.12.0-sources.jar: io/burkard/cdk/services/acmpca/cfnCertificateAuthority/SubjectProperty.scala <==
package io.burkard.cdk.services.acmpca.cfnCertificateAuthority

@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object SubjectProperty {

  def apply(
    organization: Option[String] = None,
    serialNumber: Option[String] = None,
    givenName: Option[String] = None,
    state: Option[String] = None,
    initials: Option[String] = None,
    commonName: Option[String] = None,
    surname: Option[String] = None,
    organizationalUnit: Option[String] = None,
    country: Option[String] = None,
    pseudonym: Option[String] = None,
    generationQualifier: Option[String] = None,
    distinguishedNameQualifier: Option[String] = None,
    title: Option[String] = None,
    locality: Option[String] = None
  ): software.amazon.awscdk.services.acmpca.CfnCertificateAuthority.SubjectProperty =
    (new software.amazon.awscdk.services.acmpca.CfnCertificateAuthority.SubjectProperty.Builder)
      .organization(organization.orNull)
      .serialNumber(serialNumber.orNull)
      .givenName(givenName.orNull)
      .state(state.orNull)
      .initials(initials.orNull)
      .commonName(commonName.orNull)
      .surname(surname.orNull)
      .organizationalUnit(organizationalUnit.orNull)
      .country(country.orNull)
      .pseudonym(pseudonym.orNull)
      .generationQualifier(generationQualifier.orNull)
      .distinguishedNameQualifier(distinguishedNameQualifier.orNull)
      .title(title.orNull)
      .locality(locality.orNull)
      .build()
}

==> aws-cdk-scala_2.13-0.19.0-sources.jar: io/burkard/cdk/services/acmpca/cfnCertificateAuthority/SubjectProperty.scala <==
package io.burkard.cdk.services.acmpca.cfnCertificateAuthority

import scala.collection.JavaConverters._

@scala.annotation.nowarn("cat=deprecation")
@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object SubjectProperty {

  def apply(
    organization: Option[String] = None,
    serialNumber: Option[String] = None,
    givenName: Option[String] = None,
    state: Option[String] = None,
    initials: Option[String] = None,
    commonName: Option[String] = None,
    surname: Option[String] = None,
    organizationalUnit: Option[String] = None,
    country: Option[String] = None,
    pseudonym: Option[String] = None,
    generationQualifier: Option[String] = None,
    customAttributes: Option[List[_]] = None,
    distinguishedNameQualifier: Option[String] = None,
    title: Option[String] = None,
    locality: Option[String] = None
  ): software.amazon.awscdk.services.acmpca.CfnCertificateAuthority.SubjectProperty =
    (new software.amazon.awscdk.services.acmpca.CfnCertificateAuthority.SubjectProperty.Builder)
      .organization(organization.orNull)
      .serialNumber(serialNumber.orNull)
      .givenName(givenName.orNull)
      .state(state.orNull)
      .initials(initials.orNull)
      .commonName(commonName.orNull)
      .surname(surname.orNull)
      .organizationalUnit(organizationalUnit.orNull)
      .country(country.orNull)
      .pseudonym(pseudonym.orNull)
      .generationQualifier(generationQualifier.orNull)
      .customAttributes(customAttributes.map(_.asJava).orNull)
      .distinguishedNameQualifier(distinguishedNameQualifier.orNull)
      .title(title.orNull)
      .locality(locality.orNull)
      .build()
}
